<?php
/*
 * Theme.fm Dashboard Reader
 *
 * This file adds a dashboard reader tuned to the Theme.fm RSS feed
 * Stay up to date with what's happening in the theming world of WordPress.
 *
 * @version 1.0
 */

// Don't duplicate the dashboard widget, only activate if hasn't
// been activated by another theme or plugin.
if ( ! defined( 'THEMEFM_DASHBOARD_READER_ACTIVE' ) && ! class_exists( 'Themefm_Dashboard_Reader' ) ) {
	class Themefm_Dashboard_Reader {
	
		/*
		 * Constructor, fired during admin_init
		 */
		function __construct() {
			add_action( 'wp_dashboard_setup', array( &$this, 'dashboard_setup' ) );
		}
	
		/* 
		 * Dashboard Setup
		 *
		 * Uses the wp_add_dashboard_widget function to register a new dashboard
		 * widget for Theme.fm. Callback is dashboard_content.
		 */
		function dashboard_setup() {
			wp_add_dashboard_widget('themefm-dashboard-reader', 'Latest from Theme.fm' , array( &$this, 'dashboard_content' ), $control_callback = null);
		}
	
		/*
		 * Dashboard Content
		 *
		 * The actual content of the Theme.fm Dashboard Reader,
		 * fires a fetch_feed request to the feed URL which takes
		 * care of the parsing and caching.
		 */
		function dashboard_content() {
			$feed = fetch_feed( 'http://theme.fm/feed/' );

			if ( ! is_wp_error( $feed) ):
			
				// Get a maximum of 5 items
				$maxitems = $feed->get_item_quantity( 5 );
				$items = $feed->get_items( 0, $maxitems );
			
				foreach ( $items as $item ):
			?>
				<p class="rss-widget">
					<a href="<?php echo $item->get_permalink(); ?>"><?php echo $item->get_title(); ?></a> <span class="rss-date"><?php echo $item->get_date( 'F j, Y' ); ?></span><br />
					<?php echo $item->get_description(); ?>
				</p>
			<?php
				endforeach;
			else: // Returned WP_Error, unable to fetch the feed.
			?>
				<p>There was an error fetching the Theme.fm feed, please try again later</p>
			<?php
			endif;
			?>
		
			<p class="description">&mdash; Read more on <a href="http://theme.fm">Theme.fm</a></p>
			<?php
		}
	};

	add_action( 'admin_init', create_function( '', 'global $themefm_dashboard_reader; $themefm_dashboard_reader = new Themefm_Dashboard_Reader();' ) );
	define( 'THEMEFM_DASHBOARD_READER_ACTIVE', true );
}